@@ -14,7 +14,7 @@ from alembic import command
 from alembic.util import CommandError
 
 alembic_version = tuple([int(v) for v in __alembic_version__.split('.')[0:3]])
-log = logging.getLogger()
+log = logging.getLogger(__name__)
 
 
 class _MigrateConfig(object):
@@ -54,8 +54,8 @@ class Migrate(object):
         self.alembic_ctx_kwargs.update(kwargs)
         if not hasattr(app, 'extensions'):
             app.extensions = {}
-        app.extensions['migrate'] = _MigrateConfig(self, self.db,
-            **self.alembic_ctx_kwargs)
+        app.extensions['migrate'] = _MigrateConfig(
+            self, self.db, **self.alembic_ctx_kwargs)
 
     def configure(self, f):
         self.configure_callbacks.append(f)
@@ -307,21 +307,26 @@ def show(directory=None, revision='head'):
     command.show(config, revision)
 
 
-@MigrateCommand.option('-i', '--indicate-current', dest='indicate_current', action='store_true',
-                       default=False, help='Indicate current version (Alembic 0.9.9 or greater is required)')
+@MigrateCommand.option('-i', '--indicate-current', dest='indicate_current',
+                       action='store_true', default=False,
+                       help=('Indicate current version (Alembic 0.9.9 or '
+                             'greater is required)'))
 @MigrateCommand.option('-v', '--verbose', dest='verbose', action='store_true',
                        default=False, help='Use more verbose output')
 @MigrateCommand.option('-r', '--rev-range', dest='rev_range', default=None,
-                       help='Specify a revision range; format is [start]:[end]')
+                       help=('Specify a revision range; format is '
+                             '[start]:[end]'))
 @MigrateCommand.option('-d', '--directory', dest='directory', default=None,
                        help=("Migration script directory (default is "
                              "'migrations')"))
 @catch_errors
-def history(directory=None, rev_range=None, verbose=False, indicate_current=False):
+def history(directory=None, rev_range=None, verbose=False,
+            indicate_current=False):
     """List changeset scripts in chronological order."""
     config = current_app.extensions['migrate'].migrate.get_config(directory)
     if alembic_version >= (0, 9, 9):
-        command.history(config, rev_range, verbose=verbose, indicate_current=indicate_current)
+        command.history(config, rev_range, verbose=verbose,
+                        indicate_current=indicate_current)
     else:
         command.history(config, rev_range, verbose=verbose)
 
@@ -354,19 +359,16 @@ def branches(directory=None, verbose=False):
     command.branches(config, verbose=verbose)
 
 
-@MigrateCommand.option('--head-only', dest='head_only', action='store_true',
-                       default=False,
-                       help='Deprecated. Use --verbose for additional output')
 @MigrateCommand.option('-v', '--verbose', dest='verbose', action='store_true',
                        default=False, help='Use more verbose output')
 @MigrateCommand.option('-d', '--directory', dest='directory', default=None,
                        help=("Migration script directory (default is "
                              "'migrations')"))
 @catch_errors
-def current(directory=None, verbose=False, head_only=False):
+def current(directory=None, verbose=False):
     """Display the current revision for each database."""
     config = current_app.extensions['migrate'].migrate.get_config(directory)
-    command.current(config, verbose=verbose, head_only=head_only)
+    command.current(config, verbose=verbose)
 
 
 @MigrateCommand.option('--tag', dest='tag', default=None,
